California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 007 - RENEWABLE ENERGY GENERATION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302703 | YES ON PROPOSITION 7 - CALIFORNIANS FOR SOLAR AND CLEAN ENERGY - A COALITION OF CLIMATE SCIENTISTS, CONSUMER, ENVIRONMENTAL, AND COMMUNITY LEADERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304245 | CALIFORNIANS AGAINST ANOTHER COSTLY ENERGY SCHEME - NO ON 7, MAJOR FUNDING FROM PG&E CORP AND SO.CAL. EDISON COMPANY, A COALITION OF ENVIRONMENTALISTS, RENEWABLE ENERGY COMPANIES, TAXPAYERS, AND LABOR | OPPOSE